@@ -65,7 +65,8 @@ bayessurvreg2.priorBeta <- function(prior.beta, init, design)
       init.beta <- numeric(0)    
       mean.prior <- numeric(0)
       var.prior <- numeric(0)
-      parmI <- c(0, 0, 0, 1*design$randomInt, design$indb)
+      if (is.null(design$indb)) parmI <- c(0, 0, 0, 1*design$randomInt, 0)
+      else                      parmI <- c(0, 0, 0, 1*design$randomInt, design$indb)
       parmD <- c(0, 0, 0)
       names(parmI) <- c("nbeta", "nFixed", "ngamma", "randomIntcpt", "indbA")
       names(parmD) <- c("beta", "mean.beta", "var.beta")    
